# API Endpoints
API_URL_PRODUCTION = "https://api.eka.care"
API_URL_SANDBOX = "https://api.dev.eka.care"

# Document Types
DOCUMENT_TYPE_LAB_REPORT = "lr"
DOCUMENT_TYPE_PRESCRIPTION = "ps"
DOCUMENT_TYPE_DISCHARGE_SUMMARY = "ds"
DOCUMENT_TYPE_VACCINE_CERTIFICATE = "vc"
DOCUMENT_TYPE_INSURANCE = "in"
DOCUMENT_TYPE_INVOICE = "iv"
DOCUMENT_TYPE_SCAN = "sc"
DOCUMENT_TYPE_OTHER = "ot"

# Webhook Event Types
WEBHOOK_EVENT_APPOINTMENT_CREATED = "appointment.created"
WEBHOOK_EVENT_APPOINTMENT_UPDATED = "appointment.updated"
WEBHOOK_EVENT_PRESCRIPTION_CREATED = "prescription.created"
WEBHOOK_EVENT_PRESCRIPTION_UPDATED = "prescription.updated"

# ABDM Consent Status
CONSENT_STATUS_REQUESTED = "requested"
CONSENT_STATUS_GRANTED = "granted"
CONSENT_STATUS_EXPIRED = "expired"
CONSENT_STATUS_DENIED = "denied"
CONSENT_STATUS_REVOKED = "revoked"

# ABDM Health Information Types
HI_TYPE_OP_CONSULTATION = "OPConsultation"
HI_TYPE_PRESCRIPTION = "Prescription"
HI_TYPE_DISCHARGE_SUMMARY = "DischargeSummary"
HI_TYPE_DIAGNOSTIC_REPORT = "DiagnosticReport"
HI_TYPE_IMMUNIZATION_RECORD = "ImmunizationRecord"
HI_TYPE_HEALTH_DOCUMENT_RECORD = "HealthDocumentRecord"
HI_TYPE_WELLNESS_RECORD = "WellnessRecord"

# Vital LOINC Codes
LOINC_HEART_RATE = "8867-4"
LOINC_BLOOD_GLUCOSE_RANDOM = "74774-1"
LOINC_BLOOD_GLUCOSE_FASTING = "1558-6"
LOINC_BLOOD_GLUCOSE_AFTER_FOOD = "1521-4"
LOINC_BLOOD_OXYGEN = "2708-6"
LOINC_SYSTOLIC_BP = "8480-6"
LOINC_DIASTOLIC_BP = "8462-4"
LOINC_HEIGHT = "8302-2"
LOINC_BMI = "39156-5"
